@@ -13,8 +13,10 @@ from .abc.lookup import Lookup
 from .abc.lookup import MappingLookup
 from .abc.lookup import DictionaryLookup
 from .fileloader import load_json_file
+
 from .matrix.matrix import Matrix, PersistentMatrix
 from .matrix.namedmatrix import NamedMatrix, PersistentNamedMatrix
+from .model.model import Model
 
 from .abc.anomaly import Anomaly
 
@@ -39,6 +41,7 @@ __all__ = (
 	"Matrix",
 	"PersistentMatrix",
 	"NamedMatrix",
+	"Model",
 	"PersistentNamedMatrix",
 	"Anomaly",
 
