@@ -18,6 +18,7 @@ class BSPumpService(asab.Service):
 		self.Pipelines = dict()
 		self.Connections = dict()
 		self.Lookups = dict()
+		self.LookupFactories = []
 		self.Matrixes = dict()
 
 
@@ -55,6 +56,9 @@ class BSPumpService(asab.Service):
 		for pipeline in pipelines:
 			self.add_pipeline(pipeline)
 
+	def del_pipeline(self, pipeline):
+		del self.Pipelines[pipeline.Id]
+
 	# Connections
 
 	def add_connection(self, connection):
@@ -95,8 +99,17 @@ class BSPumpService(asab.Service):
 		try:
 			return self.Lookups[lookup_id]
 		except KeyError:
+			for lookup_factory in self.LookupFactories:
+				lookup = lookup_factory.locate_lookup(lookup_id)
+				if lookup is not None:
+					self.Lookups[lookup_id] = lookup
+					return lookup
 			raise KeyError("Cannot find lookup id '{}' (did you call add_lookup() ?)".format(lookup_id))
 
+	def add_lookup_factory(self, lookup_factory):
+		self.LookupFactories.append(lookup_factory)
+
+
 	# Matrixes
 
 	def add_matrix(self, matrix):
