@@ -1,5 +1,9 @@
+import logging
 from ..abc.source import TriggerSource
 
+L = logging.getLogger(__name__)
+
+
 
 class UnitTestSource(TriggerSource):
 
@@ -7,6 +11,11 @@ class UnitTestSource(TriggerSource):
 		super().__init__(app, pipeline, id=id, config=config)
 		self.Input = []
 
+
 	async def cycle(self, *args, **kwags):
-		for context, event in self.Input:
-			await self.process(event, context=context)
+		try:
+			for context, event in self.Input:
+				await self.process(event, context=context)
+		except Exception as e:
+			L.exception("During unit test")
+			raise e
